============================
Ksyun Cloud SDK for Python
============================

Ksyun Cloud Python SDK is the official software development kit, which allows Python developers to write software that makes use of ksyun Cloud services.

The SDK works on Python versions:

   * 2.7 and greater, including 3.x

Quick Start
-----------
First, install the library:

.. code-block:: sh

    $ pip install kingsoftcloud-sdk-python

or download source code from github and install:

.. code-block:: sh

    $ git clone https://github.com/kingsoftcloud/sdk-python
    $ cd kingsoftcloud-sdk-python
    $ python setup.py install
